# hammer_sh Python Package

[![Version](https://img.shields.io/pypi/v/hammer_sh.svg)](https://pypi.python.org/pypi/hammer_sh) 
[![Support Python versions](https://img.shields.io/pypi/pyversions/hammer_sh.svg)](https://pypi.python.org/pypi/hammer_sh)

This is a Python package I wrote for my master thesis. It contains useful functions for pdf extraction, data preparation, training with transformers and for evaluation.

Installing
----------

Install and update using `pip`:

    $ pip install hammer_sh

